@@ -10,15 +10,6 @@
 #'
 #' @templateVar ids.default all
 #' @template ids
-#' @param flatten [\code{logical(1)}]\cr
-#'   Transform the job parameters and/or resource specifications to data frame columns?
-#'   Defaults to \code{TRUE} if all parameters (or resources) are scalar atomics.
-#'   Otherwise each row of the column will hold a named list.
-#'   New columns will be named using \code{prefix}.
-#' @param prefix [\code{logical(1)}]\cr
-#'   If set to \code{TRUE}, the prefix \dQuote{par.} is used to name column names of parameters
-#'   for a \code{\link{Registry}} and prefixes \dQuote{prob.par.} and \dQuote{algo.par.} are used to name
-#'   the columns of a \code{\link{ExperimentRegistry}}. Resources are prefixed with \dQuote{res.}.
 #' @template reg
 #' @return [\code{\link{data.table}}] with the following columns (not necessarily in this order):
 #'   \describe{
@@ -33,8 +24,8 @@
 #'     \item{job.hash}{Unique string identifying the job or chunk.}
 #'     \item{time.queued}{Time in seconds (as \code{\link[base]{difftime}}) the job was queued.}
 #'     \item{time.running}{Time in seconds (as \code{\link[base]{difftime}}) the job was running.}
-#'     \item{pars}{List of parameters/arguments for this job. Possibly expanded to separate columns (see \code{prefix}.}
-#'     \item{resources}{List of computational resources set for this job. Possibly expanded to separate columns (see \code{prefix}.}
+#'     \item{pars}{List of parameters/arguments for this job.}
+#'     \item{resources}{List of computational resources set for this job.}
 #'     \item{tags}{Tags as joined string, delimited by \dQuote{,}.}
 #'     \item{problem}{Only for \code{\link{ExperimentRegistry}}: the problem identifier.}
 #'     \item{algorithm}{Only for \code{\link{ExperimentRegistry}}: the algorithm identifier.}
@@ -50,20 +41,20 @@
 #' addJobTags(2, "tag2", reg = tmp)
 #'
 #' # Complete table:
-#' getJobTable(reg = tmp, flatten = FALSE)
+#' getJobTable(reg = tmp)
 #'
 #' # Job parameters:
-#' getJobPars(reg = tmp, flatten = FALSE)
+#' getJobPars(reg = tmp)
 #'
 #' # Set and retrieve tags:
 #' getJobTags(reg = tmp)
 #'
 #' # Job parameters with tags right-joined:
 #' rjoin(getJobPars(reg = tmp), getJobTags(reg = tmp))
-getJobTable = function(ids = NULL, flatten = NULL, prefix = FALSE, reg = getDefaultRegistry()) {
+getJobTable = function(ids = NULL, reg = getDefaultRegistry()) {
   assertRegistry(reg)
   ids = convertIds(reg, ids)
-  getJobStatus(ids, reg = reg)[getJobPars(ids, flatten = flatten, prefix = prefix, reg = reg)][getJobResources(ids = ids, flatten = flatten, reg = reg)][getJobTags(ids = ids, reg = reg)]
+  getJobStatus(ids, reg = reg)[getJobPars(ids, reg = reg)][getJobResources(ids = ids, reg = reg)][getJobTags(ids = ids, reg = reg)]
 }
 
 #' @export
@@ -84,69 +75,33 @@ getJobStatus = function(ids = NULL, reg = getDefaultRegistry()) {
 
 #' @export
 #' @rdname getJobTable
-getJobResources = function(ids = NULL, flatten = NULL, prefix = FALSE, reg = getDefaultRegistry()) {
+getJobResources = function(ids = NULL, reg = getDefaultRegistry()) {
   assertRegistry(reg)
-  if (!is.null(flatten))
-    assertFlag(flatten)
-  assertFlag(prefix)
-
   ids = convertIds(reg, ids)
   tab = merge(filter(reg$status, ids, c("job.id", "resource.id")), reg$resources, all.x = TRUE, by = "resource.id")[, c("job.id", "resources")]
-  if (flatten %??% qtestr(tab$resources, c("v1", "L", "0"), depth = 2L)) {
-    tab = rbindlist(.mapply(function(job.id, resources) c(list(job.id = job.id), resources), tab, list()), fill = TRUE)
-    if (prefix && ncol(tab) >= 2L) {
-      nn = chsetdiff(names(tab), "job.id")
-      setnames(tab, nn, stri_join("res.", nn))
-    }
-  }
   setkeyv(tab, "job.id")[]
 }
 
 #' @export
 #' @rdname getJobTable
-getJobPars = function(ids = NULL, flatten = NULL, prefix = FALSE, reg = getDefaultRegistry()) {
+getJobPars = function(ids = NULL, reg = getDefaultRegistry()) {
   assertRegistry(reg)
-  assertFlag(flatten, null.ok = TRUE)
-  assertFlag(prefix)
   UseMethod("getJobPars", object = reg)
 }
 
 
 #' @export
-getJobPars.Registry = function(ids = NULL, flatten = NULL, prefix = FALSE, reg = getDefaultRegistry()) {
+getJobPars.Registry = function(ids = NULL, reg = getDefaultRegistry()) {
   ids = convertIds(reg, ids)
-  tab = mergedJobs(reg, ids, c("job.id", "pars"))
-
-  if (flatten %??% qtestr(tab$pars, c("v1", "L"), depth = 2L)) {
-    new.cols = rbindlist(tab$pars)
-    if (ncol(new.cols) > 0L) {
-      if (prefix)
-        setnames(new.cols, names(new.cols), stri_join("par.", names(new.cols)))
-      tab[, names(new.cols) := new.cols]
-    }
-    tab[, ("pars") := NULL]
-  }
-
+  tab = mergedJobs(reg, ids, c("job.id", "job.pars"))
   setkeyv(tab, "job.id")[]
 }
 
 
 #' @export
-getJobPars.ExperimentRegistry = function(ids = NULL, flatten = NULL, prefix = FALSE, reg = getDefaultRegistry()) {
+getJobPars.ExperimentRegistry = function(ids = NULL, reg = getDefaultRegistry()) {
   ids = convertIds(reg, ids)
-  tab = mergedJobs(reg, ids, c("job.id", "pars", "problem", "algorithm"))
-
-  if (flatten %??% qtestr(tab$pars, c("v1", "L"), depth = 3L)) {
-    new.cols = rbindlist(.mapply(function(job.id, pars, ...) c(list(job.id = job.id), unlist(pars, recursive = FALSE)), tab, list()), fill = TRUE)
-    if (ncol(new.cols) >= 2L) {
-      pattern = "^(prob|algo)\\.pars\\."
-      replacement = if (prefix) "$1.par." else ""
-      setnames(new.cols, names(new.cols), stri_replace_all_regex(names(new.cols), pattern, replacement))
-      tab[, names(new.cols) := new.cols]
-    }
-    tab[, "pars" := NULL]
-  }
-
+  tab = mergedJobs(reg, ids, c("job.id", "problem", "prob.pars", "algorithm", "algo.pars"))
   setkeyv(tab, "job.id")[]
 }
 
