@@ -21,6 +21,14 @@
 #' \code{\link{clearRegistry}} completely erases all jobs from a registry, including log files and results,
 #' and thus allows you to start over.
 #'
+#' @details
+#' Currently \pkg{batchtools} understands the following options set via the configuration file:
+#' \describe{
+#'   \item{\code{cluster.functions}:}{As returned by a constructor, e.g. \code{\link{makeClusterFunctionsSlurm}}.}
+#'   \item{\code{default.resources}:}{List of resources to use. Will be overruled by resources specified via \code{\link{submitJobs}}.}
+#'   \item{\code{temp.dir}:}{Path to directory to use for temporary registries.}
+#' }
+#'
 #' @param file.dir [\code{character(1)}]\cr
 #'   Path where all files of the registry are saved.
 #'   Default is directory \dQuote{registry} in the current working directory.
@@ -86,7 +94,7 @@
 #'     \item{\code{cluster.functions} [cluster.functions]:}{Usually set in your \code{conf.file}. Set via a call to \code{\link{makeClusterFunctions}}. See example.}
 #'     \item{\code{default.resources} [named list()]:}{Usually set in your \code{conf.file}. Named list of default resources.}
 #'     \item{\code{max.concurrent.jobs} [integer(1)]:}{Usually set in your \code{conf.file}. Maximum number of concurrent jobs for a single user and current registry on the system.
-#'       \code{\link{submitJobs}} will try to respect this setting.}
+#'       \code{\link{submitJobs}} will try to respect this setting. The resource \dQuote{max.concurrent.jobs} has higher precedence.}
 #'     \item{\code{defs} [data.table]:}{Table with job definitions (i.e. parameters).}
 #'     \item{\code{status} [data.table]:}{Table holding information about the computational status. Also see \code{\link{getJobStatus}}.}
 #'     \item{\code{resources} [data.table]:}{Table holding information about the computational resources used for the job. Also see \code{\link{getJobResources}}.}
@@ -118,7 +126,7 @@ makeRegistry = function(file.dir = "registry", work.dir = getwd(), conf.file = f
   assertCharacter(source, any.missing = FALSE, min.chars = 1L)
   assertCharacter(load, any.missing = FALSE, min.chars = 1L)
   assertFlag(make.default)
-  seed = if (is.null(seed)) as.integer(runif(1L, 1, .Machine$integer.max / 2L)) else asCount(seed, positive = TRUE)
+  seed = if (is.null(seed)) as.integer(runif(1L, 0, 32768)) else asCount(seed, positive = TRUE)
 
   reg = new.env(parent = asNamespace("batchtools"))
   reg$file.dir = file.dir
@@ -133,7 +141,7 @@ makeRegistry = function(file.dir = "registry", work.dir = getwd(), conf.file = f
 
   reg$defs = data.table(
     def.id    = integer(0L),
-    pars      = list(),
+    job.pars  = list(),
     key       = "def.id")
 
   reg$status = data.table(
