@@ -50,8 +50,8 @@ findJobs = function(expr, ids = NULL, reg = getDefaultRegistry()) {
   expr = substitute(expr)
   ee = parent.frame()
   fun = function(pars) eval(expr, pars, enclos = ee)
-  pars = NULL
-  setkeyv(mergedJobs(reg, ids, c("job.id", "pars"))[vlapply(pars, fun), "job.id"], "job.id")
+  job.pars = NULL
+  setkeyv(mergedJobs(reg, ids, c("job.id", "job.pars"))[vlapply(job.pars, fun), "job.id"], "job.id")
 }
 
 #' @export
@@ -81,7 +81,7 @@ findExperiments = function(ids = NULL, prob.name = NA_character_, prob.pattern =
   assertString(algo.name, na.ok = TRUE, min.chars = 1L)
   assertString(algo.pattern, na.ok = TRUE, min.chars = 1L)
   ee = parent.frame()
-  tab = mergedJobs(reg, convertIds(reg, ids), c("job.id", "pars", "problem", "algorithm", "repl"))
+  tab = mergedJobs(reg, convertIds(reg, ids), c("job.id", "problem", "algorithm", "prob.pars", "algo.pars", "repl"))
 
   if (!is.na(prob.name)) {
     problem = NULL
@@ -111,16 +111,16 @@ findExperiments = function(ids = NULL, prob.name = NA_character_, prob.pattern =
 
   if (!missing(prob.pars)) {
     expr = substitute(prob.pars)
-    fun = function(pars) eval(expr, pars$prob.pars, enclos = ee)
-    pars = NULL
-    tab = tab[vlapply(pars, fun)]
+    fun = function(pars) eval(expr, pars, enclos = ee)
+    prob.pars = NULL
+    tab = tab[vlapply(prob.pars, fun)]
   }
 
   if (!missing(algo.pars)) {
     expr = substitute(algo.pars)
-    fun = function(pars) eval(expr, pars$algo.pars, enclos = ee)
-    pars = NULL
-    tab = tab[vlapply(pars, fun)]
+    fun = function(pars) eval(expr, pars, enclos = ee)
+    algo.pars = NULL
+    tab = tab[vlapply(algo.pars, fun)]
   }
 
   setkeyv(tab[, "job.id"], "job.id")[]
