@@ -48,7 +48,7 @@ killJobs = function(ids = NULL, reg = getDefaultRegistry()) {
     warningf("Could not kill %i jobs", sum(!tab$killed))
 
   # reset killed jobs
-  syncRegistry(reg = reg)
+  sync(reg = reg)
   cols = c("submitted", "started", "done", "error", "memory", "resource.id", "batch.id", "log.file", "job.hash")
   reg$status[tab[tab$killed], (cols) := list(NA_real_, NA_real_, NA_real_, NA_character_, NA_real_, NA_integer_, NA_character_, NA_character_, NA_character_)]
   saveRegistry(reg)
