@@ -169,11 +169,12 @@ reduceResults = function(fun, ids = NULL, init, ..., reg = getDefaultRegistry())
 #' addExperiments(prob.designs, algo.designs, reg = tmp)
 #' submitJobs(reg = tmp)
 #'
-#' # collect results and join them # with problem and algorithm paramters
-#' ijoin(
+#' # collect results and join them with problem and algorithm paramters
+#' res = ijoin(
 #'   getJobPars(reg = tmp),
 #'   reduceResultsDataTable(reg = tmp, fun = function(x) list(res = x))
 #' )
+#' flatten(res, sep = ".")
 reduceResultsList = function(ids = NULL, fun = NULL, ..., missing.val, reg = getDefaultRegistry()) {
   assertRegistry(reg, sync = TRUE)
   assertFunction(fun, null.ok = TRUE)
@@ -181,33 +182,17 @@ reduceResultsList = function(ids = NULL, fun = NULL, ..., missing.val, reg = get
   .reduceResultsList(ids, fun, ..., missing.val = missing.val, reg = reg)
 }
 
-#' @param flatten [\code{logical(1)}]\cr
-#'   Transform results into separate \code{\link[data.table]{data.table}} columns.
-#'   Defaults to \code{TRUE} if all results are (a list of) scalar atomics,
-#'   Otherwise each row of the column will hold a named list.
 #' @export
 #' @rdname reduceResultsList
-reduceResultsDataTable = function(ids = NULL, fun = NULL, ..., flatten = NULL, missing.val, reg = getDefaultRegistry()) {
+reduceResultsDataTable = function(ids = NULL, fun = NULL, ..., missing.val, reg = getDefaultRegistry()) {
   assertRegistry(reg, sync = TRUE)
   ids = convertIds(reg, ids, default = .findDone(reg = reg))
   assertFunction(fun, null.ok = TRUE)
-  assertFlag(flatten, null.ok = TRUE)
 
   results = .reduceResultsList(ids = ids, fun = fun, ..., missing.val = missing.val, reg = reg)
   if (length(results) == 0L)
     return(noIds())
-
-  if (flatten %??% qtestr(results, c("v1", "L"), depth = 2L)) {
-    if (!qtestr(results, "d"))
-      results = lapply(results, as.data.table)
-    results = rbindlist(results, fill = TRUE, idcol = "job.id")
-    if (!identical(results$job.id, seq_row(ids)))
-      stop("The function must return an object for each job which is convertible to a data.frame with one row")
-    results[, "job.id" := ids$job.id]
-    setkeyv(results, "job.id")[]
-  } else {
-    ids[, "result" := results][]
-  }
+  ids[, "result" := results][]
 }
 
 .reduceResultsList = function(ids, fun = NULL, ..., missing.val, reg = getDefaultRegistry()) {
