@@ -12,17 +12,19 @@
 #' @family Registry
 #' @export
 saveRegistry = function(reg = getDefaultRegistry()) {
-  if (reg$writeable) {
-    "!DEBUG [saveRegistry]: Saving Registry"
-
-    fn = fp(reg$file.dir, c("registry.new.rds", "registry.rds"))
-    ee = new.env(parent = asNamespace("batchtools"))
-    list2env(mget(chsetdiff(ls(reg), c("cluster.functions", "default.resources", "temp.dir")), reg), ee)
-    class(ee) = class(reg)
-    writeRDS(ee, file = fn[1L])
-    file.rename(fn[1L], fn[2L])
-  } else {
+  if (!reg$writeable) {
     "!DEBUG [saveRegistry]: Skipping saveRegistry (read-only)"
+    return(invisible(FALSE))
   }
-  invisible(reg$writeable)
+
+  "!DEBUG [saveRegistry]: Saving Registry"
+  fn = fp(reg$file.dir, c("registry.new.rds", "registry.rds"))
+  ee = new.env(parent = asNamespace("batchtools"))
+  exclude = c("cluster.functions", "default.resources", "temp.dir", "mtime", "writeable")
+  list2env(mget(chsetdiff(ls(reg), exclude), reg), ee)
+  class(ee) = class(reg)
+  writeRDS(ee, file = fn[1L])
+  file.rename(fn[1L], fn[2L])
+  reg$mtime = file.mtime(fn[2L])
+  invisible(TRUE)
 }
