@@ -50,9 +50,19 @@ batchtools$hooks = list(
     debugme::debugme()
     batchtools$debug = TRUE
   }
-  backports::import(pkgname, c("dir.exists", "hasName"))
+  backports::import(pkgname, c("dir.exists", "hasName", "...length"))
 } # nocov end
 
 .onUnload = function (libpath) { # nocov start
   library.dynam.unload("batchtools", libpath)
 } # nocov end
+
+.onAttach = function(libname, pkgname) {
+  msg = paste(
+    "Breaking change in batchtools v0.9.7:",
+    "The format of the returned data.table of the functions `reduceResultsDataTable()`, getJobTable()`, `getJobPars()`, and `getJobResources()` has changed.",
+    "List columns are not unnested automatically anymore.",
+    "To manually unnest tables, batchtools provides the helper function `flatten()` now, e.g. `flatten(getJobPars())`."
+  )
+  packageStartupMessage(msg)
+}
