@@ -76,15 +76,16 @@ test_that("lpt", {
 })
 
 test_that("caching works", {
-  reg = makeExperimentRegistry(file.dir = NA, make.default = FALSE)
+  reg = makeTestExperimentRegistry()
   p1 = addProblem(reg = reg, "p1", data = iris)
   p2 = addProblem(reg = reg, "p2", data = data.frame(a = 1:10))
-  a = addAlgorithm(reg = reg, name = "a", fun = function(data, ...) nrow(data))
+  a1 = addAlgorithm(reg = reg, name = "a1", fun = function(data, ...) nrow(data))
+  a2 = addAlgorithm(reg = reg, name = "a2", fun = function(data, ...) 2L * nrow(data))
 
   addExperiments(reg = reg)
   ids = findJobs(reg = reg)
   ids$chunk = 1L
-  submitJobs(ids, reg = reg)
+  submitAndWait(reg, ids)
 
-  expect_equal(unlist(reduceResultsList(ids, reg = reg)), c(150, 10))
+  expect_identical(unlist(reduceResultsList(ids, reg = reg)), as.integer(c(150, 300, 10, 20)))
 })
