@@ -1,7 +1,7 @@
 context("chunkIds")
 
 test_that("chunkIds", {
-  reg = makeExperimentRegistry(file.dir = NA, make.default = FALSE)
+  reg = makeTestExperimentRegistry()
   prob = addProblem(reg = reg, "p1", data = iris, fun = function(job, data, ...) nrow(data), seed = 42)
   prob = addProblem(reg = reg, "p2", data = iris, fun = function(job, data, ...) nrow(data), seed = 42)
   algo = addAlgorithm(reg = reg, "a1", fun = function(job, data, instance, sq, ...) instance^sq)
@@ -33,7 +33,7 @@ test_that("chunkIds", {
 })
 
 test_that("chunkIds with defaults", {
-  reg = makeRegistry(file.dir = NA, make.default = FALSE)
+  reg = makeTestRegistry()
   batchMap(identity, 1:10, reg = reg)
   expect_error(suppressWarnings(chunkIds(reg = reg)))
 })
