@@ -1,7 +1,7 @@
 context("measure memory")
 
 test_that("memory measurements work", {
-  reg = makeRegistry(file.dir = NA, make.default = FALSE)
+  reg = makeTestRegistry()
   ids = batchMap(function(n) { m = matrix(runif(n), nrow = 10); m %*% t(m) }, n = c(100, 1e7), reg = reg)
   submitAndWait(reg, 1:2, resources = list(measure.memory = TRUE))
 
